# Beescoop link with easy my coop

Link between beesdoo customization and easy_my_coop

Table of contents

- Bug Tracker
- Credits
  - Authors
  - Contributors
  - Maintainers

# Bug Tracker

Bugs are tracked on GitHub Issues. In case of trouble, please check there if your issue has already been reported. If you spotted it first, help us smashing it by providing a detailed and welcomed feedback.

Do not contact contributors directly about support or help with technical issues.

# Credits

## Authors

- BEES coop
- Coop IT Easy SCRLfs

## Contributors

- BEES coop
- Coop IT Easy SCRLfs

## Maintainers

This module is part of the beescoop/obeesdoo project on GitHub.

You are welcome to contribute.